//import { dispatch } from './Neo4jDispatcher'
var neo4j = require('neo4j-driver').v1
var driver = neo4j.driver("bolt://localhost:7687", neo4j.auth.basic("neo4j", "admin"))
var session = driver.session()
// // Helper functions
const constraintQuery = (label, keyName) => `CREATE CONSTRAINT ON (x:${label}) ASSERT x.${keyName} IS UNIQUE`
const extractProperties = neo4jResult => neo4jResult.records.map((node) => node._fields[0].properties)
const getFromNeo4j = (query, transform) => session.run(query).then(res => Promise.resolve(transform ? transform(res) : res)).catch(err => Promise.reject(err))
const runInNeo4j = (query) => session.run(query)//.then(res => Promise.resolve(res)).catch(err => Promise.reject(err))
const decorateIfString = value => typeof value === "string" ? `'${value}'` : value
const isKey = (propName, keyName) => propName === keyName
const isForRelationship = (propName, essentials) => essentials[propName] && essentials[propName].type === "relationship"
const reduceToSetClauses = (obj, nodeName, keyName, essentials) => Object.getOwnPropertyNames(obj)
  .filter(propName => !isKey(propName, keyName) && !isForRelationship(propName, essentials))
  .map(propName => `${nodeName}.${propName} =  ${decorateIfString(obj[propName])}`)
  .toString(' ')
const reduceToRelationshipMerges = (obj, nodeName, keyName, essentials) => Object.getOwnPropertyNames(obj)
  .filter(propName => !isKey(propName, keyName) && isForRelationship(propName, essentials))
  .map(propName => {
    let theOtherNodeName = `nodo_${essentials[propName].label}_${obj[propName]}`
    let clause = ""
    clause += `WITH ${nodeName} `
    clause += `MATCH (${theOtherNodeName}:${essentials[propName].label} { id${essentials[propName].label}: ${decorateIfString(obj[propName])} } ) `
    clause += `MERGE (${nodeName})-[:${essentials[propName].relName}]->(${theOtherNodeName})`
    return clause
  })
  .join(" ")


export default class Entity {

  constructor() {

  }

  init(config) {
    if (!config) throw new Error("Cannot contruct Entity without config object initialized")
    this.label = config.label;
    this.keyName = Object.getOwnPropertyNames(config.essentials).filter(prn => config.essentials[prn].key)[0]
    this.config = config
  }

  initializeLabel() {
    return session.run(constraintQuery(this.label, this.keyName))
      .then((result) => Promise.resolve(result))
      .catch((err) => Promise.reject(err))
  }

  getAll() {
    return getFromNeo4j(`MATCH (nodes:${this.label}) RETURN nodes`, extractProperties)
  }

  deleteAll() {
    return runInNeo4j(`MATCH (nodes:${this.label}) DETACH DELETE nodes`)
  }

  get(key) {
    return getFromNeo4j(`MATCH (nodes:${this.label} {${this.keyName}: ${decorateIfString(key)}}) RETURN nodes`, extractProperties)
  }

  update(obj) {
    var setClauses = reduceToSetClauses(obj, "n", this.keyName, this.config.essentials)
    if (setClauses) {
      return runInNeo4j(`MATCH (n:${this.label} {${this.keyName}: ${decorateIfString(obj[keyName])}}) SET ` + setClauses)
    }
  }

  setArray(arr) {

    var query = arr.reduce((res, obj) => {

      //dispatch("newItem", Object.assign({ collection: `${this.label}` }, obj))

      let varName = `nodo_${this.label}`.trim() + '_' + obj[this.keyName].trim()
      let linea = ` MERGE (${varName}:${this.label} {${this.keyName}: ${decorateIfString(obj[this.keyName])} }) `
      var setClauses = reduceToSetClauses(obj, varName, this.keyName, this.config.essentials)

      if (setClauses) {
        linea += `WITH ${varName} SET ${setClauses} `
      }

      var relClauses = reduceToRelationshipMerges(obj, varName, this.keyName, this.config.essentials)
      if (relClauses) {
        linea += relClauses
      }

      return res + linea

    }, "")
    //console.log(query)
    return runInNeo4j(query)
      .then((data) => {
        return Promise.resolve(data)
      })
      .catch((err) => {
        throw (err)
      })
  }


  set(obj) {
    return this.setArray(obj.constructor === Array ? obj : [obj])
  }

  delete(key) {
    return runInNeo4j(`MATCH (u:${this.label} { ${this.keyName}: ${decorateIfString(key)} }) DELETE u`)
  }
}
