var expect = require('chai').expect
var should = require('chai').should()
var babel = require('babel-core/register')
import Product from '../Product'

describe('Class Product', function() {
  before(function(done) {
    new Product().deleteAll()
    done()
  })
  it(`Has a good name (Product)`, function() {
    let product = new Product()
    expect(product.label).to.equal("Product")
  })
  it('at start #deleteAll should have emptied the Product label', function(done) {
    new Product().getAll()
      .then(function(data) {
        expect(JSON.stringify(data)).to.equal("[]")
        done();
      })
      .catch(function(err) {
        done(err)
      })
  })
  it('#initializeLabel should initialize the Product label', function() {
    new Product().initializeLabel()
      .then(() => done())
      .catch((err) => done(err))
  })
  it('#set should add a Product', function(done) {
    var obj = {
      idProduct: "Harina",
      nombre: "Harina leudante para reposteria"
    }
    new Product().set(obj)
      .then(() => done())
      .catch((err) => done(err))
  })
  it('#getAll should get the new Product', function(done) {
    var obj = {
      idProduct: "Harina",
      nombre: "Harina leudante para reposteria"
    }
    new Product().getAll()
      .then((data) => {
        expect(JSON.stringify(data)).to.equal(JSON.stringify([obj]))
        done()
      })
      .catch((err) => done(err))
  })
  it('#set should not duplicate the Product', function(done) {
    var obj = {
      idProduct: "Harina",
      nombre: "Harina leudante para reposteria"
    }
    new Product().set(obj)
      .then(new Product().getAll()
        .then((data) => {
          expect(data.length).to.equal(1)
          done()
        })
        .catch((err) => done())
      )
  })
  it.skip('#delete should erase a Product', (done) => {
    var obj = {
      idProduct: "Harina",
      nombre: "Harina leudante para reposteria"
    }
    new Product().delete(obj.idProduct)
      .then(() => {
        var result = new Product().getAll().then((data) => {
            expect(JSON.stringify(data)).to.equal("[]")
          })
          .catch((err) => done(err))
        done()
      })
      .catch((err) => done(err))
  })

})
