var expect = require('chai').expect
var should = require('chai').should()
var babel = require('babel-core/register')
import Location from '../Location'
let obj = {
  idLocation: "Envasado",
  parent: "root",
  nombre: "Todas las ubicaciones de Envasado"
}
describe('Class Location', function() {
  before(function(done) {
    new Location().deleteAll()
    done()
  })
  it(`Has a good name (Location)`, function() {
    let location = new Location()
    expect(location.label).to.equal("Location")
  })
  it('at start #deleteAll should have emptied the Location label', function(done) {
    new Location().getAll()
      .then(function(data) {
        expect(JSON.stringify(data)).to.equal("[]")
        done();
      })
      .catch(function(err) {
        done(err)
      })
  })
  it('#initializeLabel should initialize the Location label', function() {
    new Location().initializeLabel()
      .then(() => done())
      .catch((err) => done(err))
  })
  it('#createRootNode should add a root node in Location label', function(done) {
    var rootData = {
      idLocation: "root"
    }
    new Location().createRootNode()
      .then(() => done())
      .catch((err) => done(err))
  })
  it('#set should add a Location', function(done) {
    new Location().set(obj)
      .then(() => done())
      .catch((err) => done(err))
  })
  it('#getAll should get the new Location', function(done) {
    new Location().getAll()
      .then((data) => {
        expect(data[1].idLocation).to.equal(obj.idLocation)
        expect(data[1].nombre).to.equal(obj.nombre)
        done()
      })
      .catch((err) => done(err))
  })
  it('#set should not duplicate the Location', function(done) {
    new Location().set(obj)
      .then(new Location().getAll()
        .then((data) => {
          expect(data.length).to.equal(1)
          done()
        })
        .catch((err) => done())
      )
  })
  it.skip('#delete should erase a Location', (done) => {
    new Location().delete(obj.idLocation)
      .then(() => {
        var result = new Location().getAll().then((data) => {
            expect(JSON.stringify(data)).to.equal('[{"idLocation":"root"}]')
          })
          .catch((err) => done(err))
        done()
      })
      .catch((err) => done(err))
  })

})
