var expect = require('chai').expect
var should = require('chai').should()
var babel = require('babel-core/register')
import Move from '../Move'
let obj = {idMove: "mv00003", from: "InvIni", to:"CocHel", actor: "juan", qtyMoving: 0.8, what: "Leche", when: "2017-10-11T10:25:25", why: "Parte de la toma de inventario de la mañana del 11 de noviembre"}
describe('Class Move', function() {
  before(function(done) {
    new Move().deleteAll()
    done()
  })
  it(`Has a good name (Move)`, function() {
    let move = new Move()
    expect(move.label).to.equal("Move")
  })
  it('at start #deleteAll should have emptied the Move label', function(done) {
    new Move().getAll()
      .then(function(data) {
        expect(JSON.stringify(data)).to.equal("[]")
        done();
      })
      .catch(function(err) {
        done(err)
      })
  })
  it('#initializeLabel should initialize the Move label', function() {
    new Move().initializeLabel()
      .then(() => done())
      .catch((err) => done(err))
  })
  it('#set should add a Move', function(done) {
    new Move().set(obj)
      .then(() => done())
      .catch((err) => done(err))
  })
  it('#getAll should get the new Move', function(done) {
    new Move().getAll()
      .then((data) => {
        expect(data[0].idMove).to.equal(obj.idMove)
        expect(data[0].nombre).to.equal(obj.nombre)
        done()
      })
      .catch((err) => done(err))
  })
  it('#set should not duplicate the Move', function(done) {
    new Move().set(obj)
      .then(new Move().getAll()
        .then((data) => {
          expect(data.length).to.equal(1)
          done()
        })
        .catch((err) => done())
      )
  })
  it.skip('#delete should erase a Move', (done) => {
    new Move().delete(obj.idMove)
      .then(() => {
        var result = new Move().getAll().then((data) => {
            expect(JSON.stringify(data)).to.equal('[{"idMove":"root"}]')
          })
          .catch((err) => done(err))
        done()
      })
      .catch((err) => done(err))
  })

})
