var expect = require('chai').expect
var should = require('chai').should()
var babel = require('babel-core/register')
import Order from '../Order'
let obj = {idOrder: "ls00001", due: "2017-10-14", output:"TortaLista", qtyOrdered: 4.01}
describe('Class Order', function() {
  before(function(done) {
    new Order().deleteAll()
    done()
  })
  it(`Has a good name (Order)`, function() {
    let order = new Order()
    expect(order.label).to.equal("Order")
  })
  it('at start #deleteAll should have emptied the Order label', function(done) {
    new Order().getAll()
      .then(function(data) {
        expect(JSON.stringify(data)).to.equal("[]")
        done();
      })
      .catch(function(err) {
        done(err)
      })
  })
  it('#initializeLabel should initialize the Order label', function() {
    new Order().initializeLabel()
      .then(() => done())
      .catch((err) => done(err))
  })
  it('#set should add a Order', function(done) {
    new Order().set(obj)
      .then(() => done())
      .catch((err) => done(err))
  })
  it('#getAll should get the new Order', function(done) {
    new Order().getAll()
      .then((data) => {
        expect(data[0].idOrder).to.equal(obj.idOrder)
        expect(data[0].due).to.equal(obj.due)
        expect(data[0].qtyOrdered).to.equal(obj.qtyOrdered)
        done()
      })
      .catch((err) => done(err))
  })
  it('#set should not duplicate the Order', function(done) {
    new Order().set(obj)
      .then(new Order().getAll()
        .then((data) => {
          expect(data.length).to.equal(1)
          done()
        })
        .catch((err) => done())
      )
  })
  it.skip('#delete should erase a Order', (done) => {
    new Order().delete(obj.idOrder)
      .then(() => {
        var result = new Order().getAll().then((data) => {
            expect(JSON.stringify(data)).to.equal("[]")
          })
          .catch((err) => done(err))
        done()
      })
      .catch((err) => done(err))
  })

})
